==> open-cluster-management-cluster-model-6.6.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetBindingSpecFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ManagedClusterSetBindingSpecFluentImpl<A extends ManagedClusterSetBindingSpecFluent<A>> extends BaseFluent<A> implements ManagedClusterSetBindingSpecFluent<A>{
  public ManagedClusterSetBindingSpecFluentImpl() {
  }
  public ManagedClusterSetBindingSpecFluentImpl(ManagedClusterSetBindingSpec instance) {
    this.withClusterSet(instance.getClusterSet()); 
  }
  private String clusterSet;
  public String getClusterSet() {
    return this.clusterSet;
  }
  public A withClusterSet(String clusterSet) {
    this.clusterSet=clusterSet; return (A) this;
  }
  public Boolean hasClusterSet() {
    return this.clusterSet != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ManagedClusterSetBindingSpecFluentImpl that = (ManagedClusterSetBindingSpecFluentImpl) o;
    if (clusterSet != null ? !clusterSet.equals(that.clusterSet) :that.clusterSet != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterSet,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterSet != null) { sb.append("clusterSet:"); sb.append(clusterSet); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetBindingSpecFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ManagedClusterSetBindingSpecFluentImpl<A extends ManagedClusterSetBindingSpecFluent<A>> extends BaseFluent<A> implements ManagedClusterSetBindingSpecFluent<A>{
  public ManagedClusterSetBindingSpecFluentImpl() {
  }
  public ManagedClusterSetBindingSpecFluentImpl(ManagedClusterSetBindingSpec instance) {
    if (instance != null) {
      this.withClusterSet(instance.getClusterSet());
    }
  }
  private String clusterSet;
  public String getClusterSet() {
    return this.clusterSet;
  }
  public A withClusterSet(String clusterSet) {
    this.clusterSet=clusterSet; return (A) this;
  }
  public Boolean hasClusterSet() {
    return this.clusterSet != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ManagedClusterSetBindingSpecFluentImpl that = (ManagedClusterSetBindingSpecFluentImpl) o;
    if (!java.util.Objects.equals(clusterSet, that.clusterSet)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterSet,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterSet != null) { sb.append("clusterSet:"); sb.append(clusterSet); }
    sb.append("}");
    return sb.toString();
  }
  
}
